%define _mariadb_ver	10.11.6

Name:		galera
Version:	26.4.16
Release:	%mkrel 1
Summary:	Synchronous multi-master wsrep provider (replication engine)
Group:		System/Servers
License:	GPLv2
URL:		https://galeracluster.com/
# Actually, the truth is, we do use galera source tarball provided by MariaDB on
# following URL (without macros):
# https://mirror.vpsfree.cz/mariadb/mariadb-%%{_mariadb_ver}/galera-26.4.8/src/galera-26.4.8.tar.gz
Source0:	https://mirror.vpsfree.cz/mariadb/mariadb-%{_mariadb_ver}/%{name}-%{version}/src/%{name}-%{version}.tar.gz
Source1:	garbd.service
Source2:	garbd-wrapper
Patch0:		cmake_paths.patch
BuildRequires:	gcc-c++
BuildRequires:	cmake
BuildRequires:	systemd
BuildRequires:	asio-devel
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(check)
BuildRequires:	pkgconfig(openssl) >= 1.1
Requires:	nmap
Requires:	procps-ng

Requires(post):		systemd
Requires(preun):	systemd

%description
Galera is a fast synchronous multi-master wsrep provider (replication engine)
for transactional databases and similar applications. For more information
about wsrep API see https://launchpad.net/wsrep. For a description of Galera
replication engine see http://www.codership.com.

%prep
%setup -q
%autopatch -p1

%build
%cmake \
       -DINSTALL_LAYOUT=RPM \
       -DCMAKE_RULE_MESSAGES=OFF \
       -DINSTALL_DOCDIR="share/doc/%{name}/" \
       -DINSTALL_GARBD="sbin" \
       -DINSTALL_GARBD-SYSTEMD="sbin" \
       -DINSTALL_CONFIGURATION="/etc/sysconfig/" \
       -DINSTALL_SYSTEMD_SERVICE="lib/systemd/system" \
       -DINSTALL_LIBDIR="%{_lib}/%{name}" \
       -DINSTALL_MANPAGE="share/man/man8"

%cmake_build

%install
%cmake_install

# PATCH 1:
#   Change the Systemd service name from "garb" to "garbd"
#
#   The Galera upstream uses name "garb" for the service while providing "garbd" alias
#   Mageia downstream packaging historically used "garbd" name for the service.
#
#   Let's stick with the Mageia legacy naming, AND provide an alias to the Galera upstream name
mv %{buildroot}%{_unitdir}/garb.service %{buildroot}%{_unitdir}/garbd.service
sed -i 's/Alias=garbd.service/Alias=garb.service/g' %{buildroot}%{_unitdir}/garbd.service

# PATCH 2:
#   Fix the hardcoded paths
#     In the Systemd service file:
sed -i 's;/usr/bin/garb-systemd;/usr/sbin/garb-systemd;g' %{buildroot}%{_unitdir}/garbd.service
#     In the wrapper script:
sed -i 's;/usr/bin/garbd;/usr/sbin/garbd;g' %{buildroot}%{_sbindir}/garb-systemd

# PATCH 4:
#  Use a dedicated user for the Systemd service
#  To fix an security issue reported by Systemd:
#
## systemd[1]: /usr/lib/systemd/system/garb.service:14: Special user nobody configured, this is not safe!
##   Subject: Special user nobody configured, this is not safe!
##   Defined-By: systemd
##   Support: https://lists.freedesktop.org/mailman/listinfo/systemd-devel
##   Documentation: https://systemd.io/UIDS-GIDS
##
##   The unit garb.service is configured to use User=nobody.
##
##   This is not safe. The nobody user's main purpose on Linux-based
##   operating systems is to be the owner of files that otherwise cannot be mapped
##   to any local user. It's used by the NFS client and Linux user namespacing,
##   among others. By running a unit's processes under the identity of this user
##   they might possibly get read and even write access to such files that cannot
##   otherwise be mapped.
##
##   It is strongly recommended to avoid running services under this user identity,
##   in particular on systems using NFS or running containers. Allocate a user ID
##   specific to this service, either statically via systemd-sysusers or dynamically
##   via the DynamicUser= service setting.
sed -i 's/User=nobody/User=garb/g' %{buildroot}/usr/lib/systemd/system/garbd.service

%post
%_post_service garbd

%preun
%_preun_service garbd

%files
%doc %{_docdir}/%{name}/
%config(noreplace,missingok) %{_sysconfdir}/sysconfig/garb
%{_sbindir}/garbd
#{_sbindir}/garbd-wrapper
# PATCH 3:
#   Make sure the wrapper script is executable
%attr(755, -, -) %{_sbindir}/garb-systemd
%{_unitdir}/garbd.service
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}_smm.so
%{_mandir}/man8/garbd.8*


%changelog
* Mon Nov 27 2023 daviddavid <daviddavid> 26.4.16-1.mga9
+ Revision: 2010142
- new version: 26.4.16, fixes CVE-2023-22084 (mga#32574)

* Fri Feb 17 2023 daviddavid <daviddavid> 26.4.14-1.mga9
+ Revision: 1943697
- new version: 26.4.14 (for mariadb 10.11.2)

* Sat Dec 24 2022 wally <wally> 26.4.13-2.mga9
+ Revision: 1926470
- rebuild for boost 1.81.0

* Wed Nov 09 2022 daviddavid <daviddavid> 26.4.13-1.mga9
+ Revision: 1904898
- new version: 26.4.13 (for mariadb 10.9.4)
- switch to cmake build system
- add some fixes from fedora
+ neoclust <neoclust>
- New version 	26.4.12

* Sun Jul 03 2022 wally <wally> 26.4.8-8.mga9
+ Revision: 1867248
- rebuild for boost 1.79.0

* Sat Apr 02 2022 umeabot <umeabot> 26.4.8-7.mga9
+ Revision: 1840515
- Mageia 9 Mass Rebuild

* Wed Dec 22 2021 wally <wally> 26.4.8-6.mga9
+ Revision: 1763309
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 26.4.8-5.mga9
+ Revision: 1762601
- rebuild for boost 1.78.0

* Sat Oct 02 2021 wally <wally> 26.4.8-4.mga9
+ Revision: 1747457
- rebuild for openssl 3.0.0

* Thu Sep 09 2021 wally <wally> 26.4.8-3.mga9
+ Revision: 1744618
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 26.4.8-2.mga9
+ Revision: 1722958
- rebuild for boost 1.76.0

* Tue May 11 2021 daviddavid <daviddavid> 26.4.8-1.mga9
+ Revision: 1722458
- new version: 26.4.8

* Fri Feb 26 2021 daviddavid <daviddavid> 26.4.7-1.mga9
+ Revision: 1692304
- new version: 26.4.7

* Thu Dec 31 2020 wally <wally> 26.4.6-3.mga8
+ Revision: 1666756
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 26.4.6-2.mga8
+ Revision: 1661998
- rebuild for boost 1.74.0

* Sun Nov 08 2020 daviddavid <daviddavid> 26.4.6-1.mga8
+ Revision: 1643566
- new version: 26.4.6 (for mariadb 10.5.7)

* Mon Aug 10 2020 daviddavid <daviddavid> 26.4.5-2.mga8
+ Revision: 1612984
- new version: 26.4.5

* Sun May 24 2020 daviddavid <daviddavid> 26.4.4-1.mga8
+ Revision: 1587230
- new version: 26.4.4 (for mariadb 10.4.13)

* Sun May 03 2020 wally <wally> 26.4.3-4.mga8
+ Revision: 1578051
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 26.4.3-3.mga8
+ Revision: 1544747
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 26.4.3-2.mga8
+ Revision: 1483366
- rebuild for boost 1.72.0

* Wed Nov 06 2019 daviddavid <daviddavid> 26.4.3-1.mga8
+ Revision: 1458403
- new version: 26.4.3

* Wed Aug 28 2019 daviddavid <daviddavid> 26.4.2-1.mga8
+ Revision: 1434849
- new version: 26.4.2 (for mariadb 10.4.7)

* Fri Apr 05 2019 daviddavid <daviddavid> 25.3.26-1.mga7
+ Revision: 1385905
- new version: 25.3.26
- now scons default to Python3

* Thu Jan 10 2019 daviddavid <daviddavid> 25.3.25-1.mga7
+ Revision: 1354112
- new version: 25.3.25
+ oden <oden>
- 25.3.2
- fix correct source url
- imported package galera


* Thu Oct 24 2013 Oden Eriksson <oeriksson@mandriva.com> 23.2.7-0.mga3
- initial Mageia package
